@@ -36,8 +36,8 @@ ListView::ListView(TQWidget *parent, const char *name) :
     setResizeMode(LastColumn);
     setDragEnabled(true);
 
-    connect(this, TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-	          TQT_SLOT(rightClicked(TQListViewItem *, const TQPoint &)));
+    connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+	          TQ_SLOT(rightClicked(TQListViewItem *, const TQPoint &)));
 }
 
 TQDragObject *ListView::dragObject()
@@ -70,8 +70,8 @@ void ListView::enablePopupHandler(bool enable)
 
 	m_menu = new TDEPopupMenu(this);
 
-	m_removeSingleId = m_menu->insertItem(removeItemString(), this, TQT_SLOT(removeSelected()));
-	m_removeAllId = m_menu->insertItem("Placeholder", this, TQT_SLOT(removeAllItems()));
+	m_removeSingleId = m_menu->insertItem(removeItemString(), this, TQ_SLOT(removeSelected()));
+	m_removeAllId = m_menu->insertItem("Placeholder", this, TQ_SLOT(removeAllItems()));
     }
     else {
 	delete m_menu;
